@@ -23,6 +23,9 @@
 #if HAVE_LIBGEN_H
 #include <libgen.h>
 #endif
+#if HAVE_SYS_MOUNT_H
+#include <sys/mount.h> /* for BLKGETSIZE */
+#endif
 
 
 #define INT off_t
@@ -44,24 +47,27 @@
 #define NORMAL A_NORMAL
 #define MARKED A_REVERSE
 #define MODIFIED A_BOLD
-#define ATTRPRINTW(attr, a) { if (oldattr != (attr)) attrset(attr), oldattr = (attr); printw a; }
-#define MAXATTRPRINTW(attr, a) { if (oldattr & (~(attr))) attrset(attr & oldattr), oldattr &= (attr); printw a; }
+#define ATTRPRINTW(attr, a) do { if (oldattr != (attr)) attrset(attr), oldattr = (attr); printw a; } while (0)
+#define MAXATTRPRINTW(attr, a) do { if (oldattr & (~(attr))) attrset(attr & oldattr), oldattr &= (attr); printw a; } while (0)
 #define PRINTW(a) ATTRPRINTW(NORMAL, a)
+#ifndef getnstr
+  #define getnstr(str, n) wgetnstr(stdscr, str, n)
+#endif
 
 
 /*******************************************************************************/
 /* Configuration parameters */
 /*******************************************************************************/
-typedef enum { bySector, maximized, helpOption, LAST } optionType;
+typedef enum { bySector, maximized, LAST } modeType;
 typedef struct {
   int blocSize, lineLength, page;
-  char *shortOptionName, *longOptionName;
-} optionParams;
+} modeParams;
 
-extern optionParams options[LAST];
-extern optionType option;
+extern modeParams modes[LAST];
+extern modeType mode;
+extern int colored;
+extern char *usage;
 
-#define usage "usage: %s [-s | --sector] [-m | --maximize] [-h | --help] filename\n"
 #define pressAnyKey "(press any key)"
 
 
@@ -146,7 +152,9 @@ void displayCentered(char *msg, int line);
 void displayOneLineMessage(char *msg);
 void displayTwoLineMessage(char *msg1, char *msg2);
 void displayMessageAndWaitForKey(char *msg);
-int displayMessageAndGetString(char *msg, char **last, char *p);
+int displayMessageAndGetString(char *msg, char **last, char *p, int p_size);
+void ungetstr(char *s);
+int get_number(INT *i);
 
 
 /*******************************************************************************/
@@ -175,6 +183,7 @@ void fill_with_string(void);
 /* Small common functions declaration */
 /*******************************************************************************/
 int streq(const char *s1, const char *s2);
+int strbeginswith(const char *a, const char *prefix);
 int myceil(int a, int b);
 INT myfloor(INT a, INT b);
 int setLowBits(int p, int val);
